"""
Use this as a patch if you can't run the
examples like this (take an 'exampleName' example):

    from aleat3.applications.exampleName import run
    run()

If you can't, use the 'apps' object that packaged all
the registered examples:

    from aleat3.applications import apps
    apps.exampleName.run()
"""

__all__ = ["apps"]

from aleat3.applications import (diceInterface,
                    rouletteWinners,
                    coinWinners,
                    diceMove)

class Transfer:
    def __init__(self):
        self.diceInterface = diceInterface
        self.rouletteWinners = rouletteWinners
        self.coinWinners = coinWinners
        self.diceMove = diceMove

apps = Transfer()



# Ramz Editions Copyright (c) 2020 Copyright Holder All Rights Reserved.
"New since 0.2.3: __main__ level is now safe!"
if __name__ == '__main__':
    from constructor import *
    from applications import apps
else:
    from aleat3.constructor import *
    from aleat3.applications import apps

# Alias for the object importing:
_a3 = Aleatoryous
_aleat = Aleatoryous
_ie = InitError
_a = apps
_app = _a

# generic variables
__author__ = "Diego Ramirez (dr01191115@gmail.com) @DiddiLeija" # @DiddiLeija is from GitHub
__version__ = "0.2.8" # ignore the pre-releases / post versions


# A short guide of the Aleatoryous Object:
"""The Diddi's Aleatoryous Project.
===============================================================================================================================
INTRODUCTION

This object was created to give the folowing values:
   1. A 'dice' algorythm.
   2. A 'coin' algorythm.
   3. A 'roulette' algorythm.

Go to http://github.com/diddileija/aleat3 to check the code behind aleat3.
===============================================================================================================================
CREDITS

Created by Diego Ramirez and the Ramz Editions (c) Team. 2020 All rights reserved."""

if __name__ == '__main__':
    import time
    e = Aleatoryous()
    for k, v in {"aleatory.dice": None, "aleatory.coin": None, "aleatory.roulette": [1, 2, 3]}:
        print("Testing", k)
        d.changemode(k)
        print(d.single())
        print(k, "is OK")
        time.sleep(1)



"""
New since 0.0.9: Use console-colored functions.

This file uses Colorama (http://pypi.org/project/colorama) for colored output.
"""

__all__ = ["UNABLE",
           "output_red",
           "output_green",
           "output_yellow",
           "output_blue",
           "output_magenta",
           "output_bright"]

error_text = """Unable to load Colorama package. Some fuctions may not run correctly
without this function. You can download the package at the PyPi page:

            http://pypi.org/project/colorama
"""

try:
    from colorama import Fore, Back, Style, init
    __all__ = __all__ + ["Fore", "Back", "Style", "init"]
    UNABLE = True
    init(autoreset=True)
    def output_red(message):
        print(Fore.RED + message)

    def output_yellow(message):
        print(Fore.YELLOW + message)

    def output_green(message):
        print(Fore.GREEN + message)

    def output_blue(message):
        print(Fore.BLUE + message)

    def output_magenta(message):
        print(Fore.MAGENTA + message)

    def output_bright(message):
        print(Style.BRIGHT + message)
except ImportError:
    print(error_text)
    UNABLE = False
    def base(a):
        print(a+"\n")

    def output_red(message=None):
        base(message)

    def output_green(message=None):
        base(message)

    def output_yellow(message=None):
        base(message)

    def output_blue(message=None):
        base(message)

    def output_magenta(message=None):
        base(message)

    def output_bright(message=None):
        base(message)
except Exception as e:
           import warnings
           warnings.warn("An unexpected output ocurred: '%s'. "%str(e)
                         "Some functions may fail without that. Report this "
                         "to <github.com/diddileija/diddiparser/issues>", UserWarning)


#########################################################################################################################################
"New since 0.1.1: Module test"

def module_test():
    output_magenta("----Module Test: colored.py----")
    print("Available colors demostration:")
    output_red(" -Red output")
    output_green(" -Green output")
    output_yellow(" -Yellow output")
    output_blue(" -Blue output")
    output_magenta(" -Magenta output")
    print("Some style demostration")
    output_bright(" -Bright output")
    print("\n" + "Colorama package:", UNABLE)
    if not UNABLE:
        print(error_text)
    print()
    output_green("The module is OK.")
    output_magenta("----Test finished----")
    d = input("\n" + "Done")

if __name__ == '__main__':
    output_yellow("NOTE: When using this file as __main__ level, you are executing the module test. This operation may take some minutes.")
    module_test()



"Movement choice with aleatory.dice"

if __name__ == '__main__':
    raise Exception(f"Unable to load application file as __main__ level")

def run():
    #import time
    from aleat3 import Aleatoryous
    from aleat3.output.colored import (output_bright,
                                       output_green,
                                       output_red)
    output_bright("""Welcome to DiceMove!

Here, you must defeat a computer syntax by using our Aleatoryous dice.
Both dices will roll and the first one who gets 50 as a result will win!

(If the program pauses, press Enter to continue)\n""")
    i = input()
    a = Aleatoryous("aleatory.dice")
    b = Aleatoryous("aleatory.dice")
    aa = 0
    bb = 0
    for e in range(50):
        e = e + 1
        output_bright("Move %s:" % e)
        _a = a.single()
        _b = b.single()
        aa += _a
        bb += _b
        output_green("YOUR MOVE: %s" % _a)
        output_red("COMPUTER MOVE: %s" % _b)
        if aa >= 50:
            output_bright("YOU WON WITH %s POINTS!" % aa)
            break
        elif bb >= 50:
            output_bright("YOU LOSE!")
            break
        else:
            output_bright("""The game keeps going with points:

- YOU: %s
- COMPUTER: %s""" % (aa, bb))
            i = input()
